# About

**Baygon** is a tool for creating and running functional tests for teaching activities. It is designed to help educators and developers ensure the quality and effectiveness of their teaching materials through automated testing.

There are many agnostic testing tools out there, but most of them are either too complex to set up or too limited in their capabilities. Primarly designed to be used for student assignments, **Baygon** aims to strike a balance between ease of use and flexibility, with a focus on rendering test results in a clear and understandable way.

## Comparison with other tools

Among the many testing tools available, here are a few that are worth mentioning:

- **unittest**: A built-in Python module for writing and running tests. While it's powerful, it requires writing tests in Python code, which may not be ideal for all users. And it has a poor output format for non-developers.
- **pytest**: A popular testing framework for Python that offers a simple syntax and powerful features. However, like unittest, it requires writing tests in Python code and also has a poor output format for non-developers.
- (I don't know any other generic testing tool that is not tied to a specific programming language or framework, so please suggest some if you know any!)

## What a strange name

**Baygon** is a brand of insecticide popularized in the 80s by the commercial ads featuring [Michel Leeb](https://fr.wikipedia.org/wiki/Michel_Leeb). The name was chosen because it's a simple and short name that is easy to remember. And **Baygon** is meant to kill bugs in your code!

Though as **Baygon* is a brand of insecticide, please note that this project is not affiliated with the Baygon brand or its parent company, SC Johnson.

<iframe width="100%" height="315" src="https://www.youtube.com/embed/JUrvsrOlao4?si=jwi0qxJYlcd259Ia" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen></iframe>
